@@ -278,7 +278,7 @@
  * If the "xadd" operation is available on this architecture,
  * ISC_PLATFORM_HAVEXADD will be defined.
  */
-#undef ISC_PLATFORM_HAVEXADD
+#define ISC_PLATFORM_HAVEXADD 1
 
 /*
  * If the "xaddq" operation (64bit xadd) is available on this architecture,
@@ -290,7 +290,7 @@
  * If the 32-bit "atomic swap" operation is available on this
  * architecture, ISC_PLATFORM_HAVEATOMICSTORE" will be defined.
  */
-#undef ISC_PLATFORM_HAVEATOMICSTORE
+#define ISC_PLATFORM_HAVEATOMICSTORE 1
 
 /*
  * If the 64-bit "atomic swap" operation is available on this
@@ -302,18 +302,18 @@
  * If the "compare-and-exchange" operation is available on this architecture,
  * ISC_PLATFORM_HAVECMPXCHG will be defined.
  */
-#undef ISC_PLATFORM_HAVECMPXCHG
+#define ISC_PLATFORM_HAVECMPXCHG 1
 
 /*
  * If <stdatomic.h> is available on this architecture,
  * ISC_PLATFORM_HAVESTDATOMIC will be defined.
  */
-#undef ISC_PLATFORM_HAVESTDATOMIC
+#define ISC_PLATFORM_HAVESTDATOMIC 1
 
 /*
  * Define if gcc ASM extension is available
  */
-#undef ISC_PLATFORM_USEGCCASM
+#define ISC_PLATFORM_USEGCCASM 1
 
 /*
  * Define if Tru64 style ASM syntax must be used.
